@@ -9,32 +9,22 @@
 #ifndef XDG_DESKTOP_PORTAL_KDE_SCREENCHOOSER_DIALOG_H
 #define XDG_DESKTOP_PORTAL_KDE_SCREENCHOOSER_DIALOG_H
 
+#include "quickdialog.h"
 #include "screencast.h"
-#include <QDialog>
+#include <QEventLoop>
 
-namespace Ui
-{
-class ScreenChooserDialog;
-}
-class QItemSelection;
-
-class ScreenChooserDialog : public QDialog
+class ScreenChooserDialog : public QuickDialog
 {
     Q_OBJECT
 public:
-    ScreenChooserDialog(const QString &appName, bool multiple, QDialog *parent = nullptr, Qt::WindowFlags flags = {});
-    ~ScreenChooserDialog();
-
-    void setSourceTypes(ScreenCastPortal::SourceTypes types);
+    ScreenChooserDialog(const QString &appName, bool multiple, ScreenCastPortal::SourceTypes types);
+    ~ScreenChooserDialog() override;
 
     QList<quint32> selectedScreens() const;
     QVector<QMap<int, QVariant>> selectedWindows() const;
 
-private:
-    void selectionChanged(const QItemSelection &selected);
-
-    const bool m_multiple;
-    Ui::ScreenChooserDialog *m_dialog;
+Q_SIGNALS:
+    void clearSelection();
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_SCREENCHOOSER_DIALOG_H
